BaseMatcher
===========

This a generic base class to be used by matchers. This class itself
does not implement a working matcher. Use a matcher such as
``SimpleMatcher``, ``DistanceMatcher``, ...

.. autoclass:: leuvenmapmatching.matcher.base.BaseMatcher
   :members:
